package com.xinyilu.system.mapper.motionprescriptioninfo;

import com.xinyilu.system.domain.motionprescriptioninfo.MotionPrescriptionDict;

import java.util.List;

/**
 * 运动处方字典Mapper接口
 *
 * @author xinyilu
 * @date 2022-08-01
 */
public interface MotionPrescriptionDictMapper {
    /**
     * 查询运动处方字典
     *
     * @param id 运动处方字典主键
     * @return 运动处方字典
     */
    public MotionPrescriptionDict selectMotionPrescriptionDictById(Long id);

    /**
     * 查询运动处方字典列表
     *
     * @param motionPrescriptionDict 运动处方字典
     * @return 运动处方字典集合
     */
    public List<MotionPrescriptionDict> selectMotionPrescriptionDictList(MotionPrescriptionDict motionPrescriptionDict);

    /**
     * 新增运动处方字典
     *
     * @param motionPrescriptionDict 运动处方字典
     * @return 结果
     */
    public int insertMotionPrescriptionDict(MotionPrescriptionDict motionPrescriptionDict);

    /**
     * 修改运动处方字典
     *
     * @param motionPrescriptionDict 运动处方字典
     * @return 结果
     */
    public int updateMotionPrescriptionDict(MotionPrescriptionDict motionPrescriptionDict);

    /**
     * 删除运动处方字典
     *
     * @param id 运动处方字典主键
     * @return 结果
     */
    public int deleteMotionPrescriptionDictById(Long id);

    /**
     * 批量删除运动处方字典
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMotionPrescriptionDictByIds(Long[] ids);

    /**
     * 删除运动处方字典
     *
     * @param ids 运动处方字典主键
     * @return 结果
     */
    public int updateMotionPrescriptionDictById(Long[] ids);

}
